import { useCallback, useEffect, useState } from 'react';
import useWebSocket, { ReadyState } from 'react-use-websocket';
export const useWsApi = (wsApiUrl) => {
    const [error, setError] = useState(false);
    const [connected, setConnected] = useState(false);
    const [request, setRequest] = useState();
    const [route, setRoute] = useState();
    const [options, setOptions] = useState();
    const handleConnected = useCallback(() => {
        setConnected(true);
        setError(false);
        options?.onConnected?.();
    }, [options]);
    const handleError = useCallback((error) => {
        setError(false);
        options?.onError?.(error);
    }, [options]);
    const handleResponse = useCallback((response) => {
        setError(false);
        options?.onResponse?.(response);
    }, [options]);
    const handleDisconnected = useCallback(() => {
        setConnected(false);
        options?.onDisconnected?.();
    }, [options]);
    const { readyState, lastJsonMessage, getWebSocket, sendMessage } = useWebSocket(wsApiUrl, {
        onOpen: () => handleConnected(),
        onError: (error) => handleError(error),
        onClose: () => handleDisconnected(),
    }, !!request);
    // send request
    useEffect(() => {
        if (!route)
            return;
        if (request && readyState === ReadyState.OPEN) {
            sendMessage(JSON.stringify({
                action: route.action,
                request,
            }));
        }
    }, [request, readyState, route?.action, sendMessage]);
    // response received
    useEffect(() => {
        if (!lastJsonMessage || JSON.stringify(lastJsonMessage) === '{}')
            return;
        handleResponse(lastJsonMessage);
    }, [lastJsonMessage, getWebSocket, handleResponse]);
    const sendRequest = useCallback((request, route, options) => {
        setConnected(true);
        setRoute(route);
        setOptions(options);
        setRequest(request);
    }, []);
    const disconnect = useCallback(() => {
        getWebSocket()?.close();
        handleDisconnected?.();
    }, [getWebSocket, handleDisconnected]);
    return {
        sendRequest,
        connected,
        error,
        disconnect,
    };
};
//# sourceMappingURL=useWsApi.js.map