import { ApiGatewayManagementApiClient, DeleteConnectionCommand, PostToConnectionCommand, } from '@aws-sdk/client-apigatewaymanagementapi';
export class WsApi {
    requestHandlers = {
        '$connect': () => Promise.resolve(),
        '$disconnect': () => Promise.resolve(),
    };
    addRouteHandler(route, requestHandler) {
        this.requestHandlers[route.action] = requestHandler;
        return this;
    }
    async handleRequest(event) {
        const { body } = event;
        const { connectionId, domainName, stage, routeKey } = event.requestContext;
        if (!connectionId)
            throw 'No connectionId';
        if (!domainName)
            throw 'No domainName';
        if (!routeKey)
            throw 'No routeKey';
        if (!body)
            throw 'No body';
        const action = routeKey;
        const requestHandler = this.requestHandlers[action];
        if (!requestHandler)
            throw `No requestHandler found for action ${action}`;
        const endpoint = `https://${domainName}/${stage}`;
        const ws = new ApiGatewayManagementApiClient({ endpoint });
        await requestHandler(JSON.parse(body), {
            sendResponse: async (response) => {
                await ws.send(new PostToConnectionCommand({
                    ConnectionId: connectionId,
                    Data: JSON.stringify(response),
                }));
            },
            closeConnection: async () => {
                await ws.send(new DeleteConnectionCommand({ ConnectionId: connectionId }));
            },
            connectionId,
            endpoint,
        });
        return {
            statusCode: 200,
            body: '',
        };
    }
}
//# sourceMappingURL=WsApi.js.map